@@ -101,7 +101,7 @@ def read_data(tr_file, val_file=None, tr_pops_f=None, val_pops_f=None):
         log.info('Reading data...')
         _, _, G = read_plink('.'.join(tr_file.split('.')[:-1]))
         log.info('Processing data...')
-        tr_snps = (G.T/2).compute()
+        tr_snps = ((2-G).T/2).compute()
         del G
         gc.collect()
     else:
@@ -125,7 +125,7 @@ def read_data(tr_file, val_file=None, tr_pops_f=None, val_pops_f=None):
             log.info('Reading validation data...')
             _, _, G = read_plink('.'.join(val_file.split('.')[:-1]))
             log.info('Processing validation data...')
-            val_snps = (G.T/2).compute()
+            val_snps = ((2-G).T/2).compute()
             del G
             gc.collect()
         else:
@@ -181,4 +181,4 @@ def write_outputs(model, trX, valX, bsize, device, run_name, out_path, only_Q=Fa
         val_preds = get_model_predictions(model, valX, bsize, device)
         for i, k in enumerate(model.ks):
             np.savetxt(f'{out_path}/{run_name}_validation.{k}.Q', val_preds[i], delimiter=' ')
-    return 0
\ No newline at end of file
+    return 0
